import 'package:example/ble/ble.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support_for_wearecg12/'
    'healthrian_ble_support_for_wearecg12.dart';

final bleState = BLEState();

class BlePage extends StatelessWidget {
  const BlePage({super.key});

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        /// express a received packet which contains ecg signal
        body: Column(
          children: [
            Observer(
              key: UniqueKey(),
              builder: (context) {
                if (!bleState.isShowingGraph) return const SizedBox();
                return StreamBuilder(
                  stream: BLEManager().streams.bufferedPlotRTStreamEcg,
                  builder: (context, snapshot) {
                    if (!snapshot.hasData) {
                      return const Center(child: Text('No Stream'));
                    }
                    return Center(
                      child: Text(
                        (snapshot.data?.l2 ?? []).length.toString(),
                      ),
                    );
                  },
                );
              },
            ),
          ],
        ),

        /// control panel
        floatingActionButton: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            FloatingActionButton(
              onPressed: () async {
                bleState.isShowingGraph = !bleState.isShowingGraph;
              },
              child: const Icon(Icons.exit_to_app),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().connectDevice();
              },
              child: const Icon(Icons.bluetooth),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().disconnectDevice();
              },
              child: const Icon(Icons.bluetooth_disabled),
            ),
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().registerCharacteristics();
                await BLEManager().startMeasurementEcg();
              },
              child: const Icon(Icons.play_arrow),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().pauseMeasurementEcg();
              },
              child: const Icon(Icons.pause),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().stopMeasurementEcg();
              },
              child: const Icon(Icons.stop),
            ),
          ],
        ),
      ),
    );
  }
}
